@@ -10,6 +10,7 @@
 #include "elisaLib_export.h"
 
 #include <QObject>
+#include <QQmlEngine>
 #include <QUrl>
 #include <QMediaPlayer>
 #include <QString>
@@ -22,6 +23,8 @@ class ELISALIB_EXPORT AudioWrapper : public QObject
 {
     Q_OBJECT
 
+    QML_ELEMENT
+
     Q_PROPERTY(bool muted
                READ muted
                WRITE setMuted
